@@ -6,6 +6,7 @@ from datascope.importance.common import (
     JointUtility,
     SklearnModelAccuracy,
     SklearnModelEqualizedOddsDifference,
+    SklearnModelRocAuc,
     Utility,
     binarize,
     get_indices,
@@ -134,7 +135,7 @@ class DataDiscardScenario(DatascopeScenario, id="data-discard"):
             if "dataset" in attributes:
                 result = result and (attributes["dataset"] != "random")
             if "utility" in attributes:
-                result = result and attributes["utility"] == UtilityType.ACCURACY
+                result = result and attributes["utility"] in [UtilityType.ACCURACY, UtilityType.ROC_AUC]
 
         return result and super().is_valid_config(**attributes)
 
@@ -223,6 +224,8 @@ class DataDiscardScenario(DatascopeScenario, id="data-discard"):
                 ),
                 weights=[-0.5, 0.5],
             )
+        elif self.utility == UtilityType.ROC_AUC:
+            target_utility = JointUtility(SklearnModelRocAuc(model), weights=[-1.0])
         else:
             raise ValueError("Unknown utility type '%s'." % repr(self.utility))
 
